@@ -14,13 +14,12 @@ from collections.abc import Iterable
 from enum import Enum
 from typing import Any, Optional, Union
 
-from dateutil import rrule
 from ical.component import ComponentModel
-from ical.iter import RecurIterable
+from ical.iter import RulesetIterable
 from ical.parsing.component import parse_content
 from ical.timespan import Timespan
 from ical.types.data_types import DATA_TYPE
-from ical.types.recur import Recur
+from ical.types.recur import Frequency, Recur
 from pydantic import BaseModel, Field, root_validator
 
 __all__ = [
@@ -77,10 +76,10 @@ class Calendar(BaseModel):
     summary: str = ""
     """Title of the calendar."""
 
-    description: Optional[str]
+    description: Optional[str] = None
     """Description of the calendar."""
 
-    location: Optional[str]
+    location: Optional[str] = None
     """Geographic location of the calendar as free-form text."""
 
     timezone: Optional[str] = Field(alias="timeZone", default=None)
@@ -110,10 +109,10 @@ class CalendarBasic(BaseModel):
     summary: str = ""
     """Title of the calendar."""
 
-    description: Optional[str]
+    description: Optional[str] = None
     """Description of the calendar."""
 
-    location: Optional[str]
+    location: Optional[str] = None
     """Geographic location of the calendar as free-form text."""
 
     timezone: Optional[str] = Field(alias="timeZone", default=None)
@@ -408,17 +407,12 @@ class Recurrence(ComponentModel):
         self, dtstart: datetime.date | datetime.datetime
     ) -> Iterable[datetime.date | datetime.datetime]:
         """Return the set of recurrences as a rrule that emits start times."""
-        ruleset = rrule.rruleset()
-        for rule in self.rrule:
-            ruleset.rrule(rule.as_rrule(dtstart))
-        for rdate in self.rdate:
-            ruleset.rdate(rdate)  # type: ignore[no-untyped-call]
-        for exdate in self.exdate:
-            if not isinstance(exdate, datetime.datetime):
-                # Convert to datetime matching dateutil's logic
-                exdate = datetime.datetime.fromordinal(exdate.toordinal())
-            ruleset.exdate(exdate)  # type: ignore[no-untyped-call]
-        return RecurIterable(lambda x: x, ruleset)
+        return RulesetIterable(
+            dtstart,
+            [rule.as_rrule(dtstart) for rule in self.rrule],
+            self.rdate,
+            self.exdate,
+        )
 
     def as_recurrence(self) -> list[str]:
         """Serialize the recurrence rule as an API string."""
@@ -455,10 +449,10 @@ class Event(BaseModel):
     end: DateOrDatetime
     """The (exclusive) end time of the event."""
 
-    description: Optional[str]
+    description: Optional[str] = None
     """Description of the event, which can contain HTML."""
 
-    location: Optional[str]
+    location: Optional[str] = None
     """Geographic location of the event as free-form text."""
 
     transparency: str = Field(default="opaque")
@@ -542,6 +536,22 @@ class Event(BaseModel):
         values["recur"] = Recurrence.from_recurrence(values["recurrence"])
         return values
 
+    @root_validator
+    def _adjust_duration(cls, values: dict[str, Any]) -> dict[str, Any]:
+        """Fix events with invalid durations."""
+        _LOGGER.debug("_adjust_duration")
+        if (
+            (dtstart := values.get("start"))
+            and (dtend := values.get("end"))
+            and dtstart.date
+            and dtend.date
+            and ((dtend.date - dtstart.date) <= datetime.timedelta(days=0))
+        ):
+            # Duration is zero or negative. Default to 1 day
+            dtend.date = dtstart.date + datetime.timedelta(days=1)
+            values["end"] = dtend
+        return values
+
     @root_validator
     def _validate_rrule(cls, values: dict[str, Any]) -> dict[str, Any]:
         """The API returns invalid RRULEs that need to be coerced to valid."""
@@ -550,32 +560,50 @@ class Event(BaseModel):
             return values
         for rule in recur.rrule:
             cls._adjust_rrule(rule, dtstart)
+        recur.exdate = [
+            cls._adjust_recurrence_date(exdate, dtstart) for exdate in recur.exdate
+        ]
+        recur.rdate = [
+            cls._adjust_recurrence_date(rdate, dtstart) for rdate in recur.rdate
+        ]
         return values
 
     @classmethod
     def _adjust_rrule(cls, rule: Recur, dtstart: DateOrDatetime) -> Recur:
         """Apply fixes to the rrule."""
-        if not rule.until:
-            return rule
+        if rule.until:
+            rule.until = cls._adjust_recurrence_date(rule.until, dtstart)
+        if rule.freq == Frequency.YEARLY and rule.by_month_day and not rule.by_month:
+            # A FREQ=YEARLY;BYMONTHDAY=N rule is ambiguous and expanded
+            # differently by google calendar vs dateutil.rrule. Add a
+            # BYMONTH=Y to make it more explicitl.
+            _LOGGER.debug("Correcting BYMONTHDAY rule: %s", rule)
+            rule.by_month = [dtstart.value.month]
+        return rule
 
+    @classmethod
+    def _adjust_recurrence_date(
+        cls, date_value: datetime.datetime | datetime.date, dtstart: DateOrDatetime
+    ) -> datetime.datetime | datetime.date:
+        """Apply fixes to the recurrence rule date."""
         if dtstart.date_time:
-            if dtstart.date_time and not isinstance(rule.until, datetime.datetime):
+            if not isinstance(date_value, datetime.datetime):
                 # Convert a date to a datetime
-                rule.until = datetime.datetime.fromordinal(
-                    rule.until.toordinal()
-                ).replace(tzinfo=dtstart.date_time.tzinfo)
-            elif (
+                return datetime.datetime.fromordinal(date_value.toordinal()).replace(
+                    tzinfo=dtstart.date_time.tzinfo
+                )
+            if (
                 dtstart.date_time.tzinfo is None
-                and isinstance(rule.until, datetime.datetime)
-                and rule.until.tzinfo is not None
+                and isinstance(date_value, datetime.datetime)
+                and date_value.tzinfo is not None
             ):
                 # Date should be floating
-                rule.until = rule.until.replace(tzinfo=None)
+                return date_value.replace(tzinfo=None)
         elif dtstart.date:
-            if isinstance(rule.until, datetime.datetime):
+            if isinstance(date_value, datetime.datetime):
                 # UNTIL is a DATE-TIME but must be a DATE
-                rule.until = rule.until.date()
-        return rule
+                return date_value.date()
+        return date_value
 
     @property
     def timespan(self) -> Timespan:
